#import "PokktCustomInterstitial.h"

@implementation PokktCustomInterstitial


@synthesize delegate;

#pragma mark Pokkt Video Ads Request

- (void)requestInterstitialAdWithParameter:(NSString *)serverParameter
                                     label:(NSString *)serverLabel
                                   request:(GADCustomEventRequest *)request
{
    
    if (serverParameter == nil)
    {
        NSLog(@"Parameters are nil");
        return;
    }
    NSError *jsonError;
    NSData *objectData = [serverParameter dataUsingEncoding:NSUTF8StringEncoding];
    NSDictionary *json = [NSJSONSerialization JSONObjectWithData:objectData
                                                         options:NSJSONReadingMutableContainers
                                                           error:&jsonError];
    
    NSLog(@"Data recieved from server: %@", json);
    screenName = [json objectForKey:@"SCREEN"];
    appId =  [json objectForKey:@"APPID"];
    securityKey = [json objectForKey:@"SECKEY"];
    
    BOOL isDebug = [[json objectForKey:@"DBG"] boolValue];
    NSString *thirdPartyId = [json objectForKey:@"TPID"];
    
    [self setGDPR];

    [PokktAds setPokktConfigWithAppId:appId securityKey:securityKey];
    
    // [optional] set it to true if you want to enable logs for PokktSDK
    [PokktDebugger setDebug:isDebug];
    
    [PokktAds setThirdPartyUserId:thirdPartyId];
    
    // OPTIONAL but we SUGGEST you to implement delegates as it will help you to determine the status of your request
    
    [PokktAds cacheAd:screenName withDelegate:self];

}


- (void)presentFromRootViewController:(UIViewController *)rootViewController
{
    [self setGDPR];
    
    [PokktAds showAd:screenName withDelegate:self presentingVC:rootViewController];
}

-(void)setGDPR
{
    PACConsentStatus status =  [[PACConsentInformation sharedInstance] consentStatus];
    PokktConsentInfo *consentInfo = [[PokktConsentInfo alloc] init];
    
    if (status == PACConsentStatusNonPersonalized)
    {
        consentInfo.isGDPRApplicable = true;
        consentInfo.isGDPRConsentAvailable = false;
    }
    else if (status == PACConsentStatusPersonalized)
    {
        consentInfo.isGDPRApplicable = true;
        consentInfo.isGDPRConsentAvailable = true;
    }
    
    [PokktAds setPokktConsentInfo:consentInfo];
}
#pragma mark Pokkt Interstitial Ads Delegates

- (void) adClosed:(NSString*) screenId adCompleted:(BOOL) adCompleted
{
    adType = No_Ad;
    [self.delegate customEventInterstitialWillDismiss:self];
    [self.delegate customEventInterstitialDidDismiss:self];
}

- (void) adClicked:(NSString*) screenId
{
    [self.delegate customEventInterstitialWasClicked:self];
}

- (void)adGratified:(NSString *)screenId withReward:(double)reward
{
}

- (void)adCachingResult:(NSString *)screenId isSuccess:(BOOL)success withReward:(double)reward errorMessage:(NSString *)errorMessage {
    if([errorMessage  isEqual: @""] || success == YES) {
        adType = Interstitial_Ad;
        [self.delegate customEventInterstitialDidReceiveAd:self];
    } else {
        adType = No_Ad;
        NSError *err = [NSError errorWithDomain:@"Error"
                                           code:0
                                       userInfo:@{
                                                  NSLocalizedDescriptionKey:errorMessage
                                                  }];
        [self.delegate customEventInterstitial:self didFailAd:err];
    }
}

- (void)adDisplayResult:(NSString *)screenId isSuccess:(BOOL)success errorMessage:(NSString *)errorMessage {
    NSString *msg = @"";
    if([errorMessage  isEqual: @""] || success == YES) {
        [self.delegate customEventInterstitialWillPresent:self];
    } else {
        msg = [NSString stringWithFormat:@"ad falied to show for %@ with error %@", screenId, errorMessage];
    }
    
    [PokktDebugger showToast:msg viewController:self];
}

@end
